@@ -171,9 +171,11 @@ class KernelDict(dict):
     def __getitem__(self, item):
         if isinstance(item, str):
             return KernelDispatcher(item, self)
-        return super().__getitem__(item)
+        return dict.__getitem__(self, item)
 
     def __getattr__(self, attr):
+        if attr.startswith("__"):
+            raise AttributeError(attr)
         return KernelDispatcher(attr, self)
 
 
@@ -233,6 +235,9 @@ class XContext(ABC):
         self._kernels = KernelDict()
         self._buffers = []
 
+    def __str__(self):
+        return type(self).__name__
+
     def new_buffer(self, capacity=1048576):
         buf = self._make_buffer(capacity=capacity)
         self.buffers.append(weakref.finalize(buf, log.debug, "free buf"))
@@ -649,6 +654,8 @@ def get_context_from_string(ctxstr):
     if ctxtype == "ContextCpu":
         if len(option) == 0:
             return xo.ContextCpu()
+        elif option[0] == "auto":
+            return xo.ContextCpu(omp_num_threads="auto")
         else:
             return xo.ContextCpu(omp_num_threads=int(option[0]))
     elif ctxtype == "ContextCupy":
@@ -672,14 +679,14 @@ def get_test_contexts():
     ctxstr = os.environ.get("XOBJECTS_TEST_CONTEXTS")
     if ctxstr is None:
         yield xo.ContextCpu()
-        # yield xo.ContextCpu(omp_num_threads=2)
+        yield xo.ContextCpu(omp_num_threads="auto")
         if xo.ContextCupy in xo.context.available:
             yield xo.ContextCupy()
         if xo.ContextPyopencl in xo.context.available:
             yield xo.ContextPyopencl()
     elif ctxstr == "all":
         yield xo.ContextCpu()
-        yield xo.ContextCpu(omp_num_threads=2)
+        yield xo.ContextCpu(omp_num_threads="auto")
         if xo.ContextCupy in xo.context.available:
             yield xo.ContextCupy()
         if xo.ContextPyopencl in xo.context.available:
@@ -702,6 +709,7 @@ def get_user_context():
        ContextPyopencl      -> ContextPyopencl()
        ContextCpu           -> ContextCpu()
        ContextCpu:2         -> ContextCpu(omp_num_threads=2)
+       ContextCpu:auto      -> ContextCpu(omp_num_threads='auto')
        ContextCupy:0        -> ContextCupy(device=0)
     """
     import os
