@@ -14,6 +14,9 @@ from typing import Callable, Dict, List, Sequence, Tuple
 from .general import _print
 
 import numpy as np
+import scipy as sp
+
+_forbid_compile = False
 
 from .context import (
     Kernel,
@@ -133,13 +136,21 @@ class ContextCpu(XContext):
         return LinkedArrayCpu
 
     def __init__(self, omp_num_threads=0):
+        """
+        Create a new CPU context, serial or with parallelization using OpenMP.
+        Args:
+            omp_num_threads (int | Literal['auto']): Number of threads to be
+            used by OpenMP. If 0, no parallelization is used. If 'auto', the
+            number of threads is selected automatically by OpenMP.
+        """
         super().__init__()
         self.omp_num_threads = omp_num_threads
 
-        if self.omp_num_threads > 1:
-            raise NotImplementedError(
-                "OpenMP parallelization not yet supported!"
-            )
+    def __str__(self):
+        if not self.openmp_enabled:
+            return super().__str__()
+        else:
+            return f"{type(self).__name__}:{self.omp_num_threads}"
 
     def _make_buffer(self, capacity):
         return BufferNumpy(capacity=capacity, context=self)
@@ -292,6 +303,9 @@ class ContextCpu(XContext):
             cdefs = "\n".join(cls._gen_c_decl({}) for cls in classes)
             cdefs += "\n" + extra_cdef
 
+            if _forbid_compile:
+                raise RuntimeError("Compilation is forbidden")
+
             so_file = self.compile_kernel(
                 module_name,
                 kernel_descriptions,
@@ -384,8 +398,9 @@ class ContextCpu(XContext):
                 ffi_interface.cdef(signature)
                 log.debug(f"cffi def {pyname} {signature}")
 
-        if self.omp_num_threads > 0:
+        if self.openmp_enabled:
             ffi_interface.cdef("void omp_set_num_threads(int);")
+            ffi_interface.cdef("int omp_get_max_threads();")
 
         # Compile
         xtr_compile_args = ["-std=c99"]
@@ -393,10 +408,16 @@ class ContextCpu(XContext):
         xtr_compile_args += extra_compile_args
         xtr_link_args += extra_link_args
 
-        if self.omp_num_threads > 0:
+        if self.openmp_enabled:
             xtr_compile_args.append("-fopenmp")
             xtr_link_args.append("-fopenmp")
 
+            # https://mac.r-project.org/openmp/
+            # on macos comment the above and uncomment the below flags to compile OpenMP with Xcode clang:
+            # xtr_compile_args.append("-Xclang")
+            # xtr_compile_args.append("-fopenmp")
+            # xtr_link_args.append("-lomp")
+
         if os.name == "nt":  # windows
             # TODO: to be handled properly
             xtr_compile_args = []
@@ -444,7 +465,7 @@ class ContextCpu(XContext):
 
         headers = ["#include <stdint.h>"]
 
-        if self.omp_num_threads > 0:
+        if self.openmp_enabled:
             headers = ["#include <omp.h>"] + headers
 
         headers += extra_headers
@@ -452,7 +473,7 @@ class ContextCpu(XContext):
         source, folders = _concatenate_sources(sources, apply_to_source)
 
         if specialize:
-            if self.omp_num_threads > 0:
+            if self.openmp_enabled:
                 specialize_for = "cpu_openmp"
             else:
                 specialize_for = "cpu_serial"
@@ -481,9 +502,9 @@ class ContextCpu(XContext):
         module = importlib.util.module_from_spec(spec)
         spec.loader.exec_module(module)
 
-        if self.omp_num_threads > 0:
-            raise NotImplementedError("OpenMP not supported for now!")
+        if self.openmp_enabled:
             self.omp_set_num_threads = module.lib.omp_set_num_threads
+            self.omp_get_max_threads = module.lib.omp_get_max_threads
 
         return module
 
@@ -526,6 +547,16 @@ class ContextCpu(XContext):
 
         return np
 
+    @property
+    def splike_lib(self):
+        """
+        Module containing all the scipy features. Numpy members should be accessed
+        through ``splike_lib`` to keep compatibility with the other contexts.
+
+        """
+
+        return sp
+
     def synchronize(self):
         """
         Ensures that all computations submitted to the context are completed.
@@ -566,7 +597,11 @@ class ContextCpu(XContext):
             # Inverse tranform (in place)
             plan.itransform(data2)
         """
-        return FFTCpu(data, axes, threads=self.omp_num_threads)
+        try:
+            num_threads = self.omp_get_max_threads()
+        except AttributeError:
+            num_threads = 1
+        return FFTCpu(data, axes, threads=num_threads)
 
     @property
     def kernels(self):
@@ -577,6 +612,18 @@ class ContextCpu(XContext):
 
         return self._kernels
 
+    @property
+    def openmp_enabled(self):
+        return self.omp_num_threads != 0
+
+    def __getstate__(self):
+        state = self.__dict__.copy()
+        state["_kernels"] = {}
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+
 
 class BufferByteArray(XBuffer):
     def _make_context(self):
@@ -760,8 +807,9 @@ class KernelCpu:
             vv = kwargs[arg.name]
             arg_list.append(self.to_function_arg(arg, vv))
 
-        if self.context.omp_num_threads > 0:
-            self.context.omp_set_num_threads(self.context.omp_num_threads)
+        if self.context.openmp_enabled:
+            if isinstance(self.context.omp_num_threads, int):
+                self.context.omp_set_num_threads(self.context.omp_num_threads)
 
         ret = self.function(*arg_list)
 
