@@ -100,9 +100,9 @@ class ContextPyopencl(XContext):
     @classmethod
     def print_devices(cls):
         for ip, platform in enumerate(cl.get_platforms()):
-            print(f"Context {ip}: {platform.name}")
+            print(f"Platform {ip}  : {platform.name}")
             for id, device in enumerate(platform.get_devices()):
-                print(f"Device {ip}.{id}: {device.name}")
+                print(f"Device   {ip}.{id}: {device.name}")
 
     def __init__(
         self, device=None, patch_pyopencl_array=True, minimum_alignment=None
@@ -135,12 +135,12 @@ class ContextPyopencl(XContext):
         else:
             if isinstance(device, str):
                 platform, device = map(int, device.split("."))
+                self.platform = cl.get_platforms()[platform]
+                self.device = self.platform.get_devices()[device]
             else:
                 self.device = device
                 self.platform = device.platform
 
-            self.platform = cl.get_platforms()[platform]
-            self.device = self.platform.get_devices()[device]
             self.context = cl.Context([self.device])
 
         self.queue = cl.CommandQueue(self.context)
@@ -273,6 +273,13 @@ class ContextPyopencl(XContext):
         """
         return cla
 
+    @property
+    def splike_lib(self):
+        """
+        Scipy features are not available through openCL
+        """
+        raise NotImplementedError
+
     def synchronize(self):
         """
         Ensures that all computations submitted to the context are completed.
