@@ -301,7 +301,13 @@ class HybridClass(metaclass=MetaHybridClass):
 
         if hasattr(obj, "_store_in_to_dict"):
             for nn in obj._store_in_to_dict:
-                out[nn] = getattr(obj, nn)
+                ww = getattr(obj, nn)
+                if hasattr(ww, "to_dict"):
+                    out[nn] = ww.to_dict()
+                elif hasattr(ww, "_to_dict"):
+                    out[nn] = ww._to_dict()
+                else:
+                    out[nn] = ww
 
         return out
 
@@ -336,6 +342,15 @@ class HybridClass(metaclass=MetaHybridClass):
     def _context(self):
         return self._xobject._buffer.context
 
+    def __getstate__(self):
+        return self._xobject.__getstate__()
+
+    def __setstate__(self, state):
+        self._xobject = self._XoStruct._from_buffer(
+            buffer=state[0], offset=state[1]
+        )
+        self._reinit_from_xobject(_xobject=self._xobject)
+
     @property
     def XoStruct(self):
         raise NameError(
@@ -351,6 +366,10 @@ class HybridClass(metaclass=MetaHybridClass):
     def compile_kernels(self, *args, **kwargs):
         return self._xobject.compile_kernels(*args, **kwargs)
 
+    def __repr__(self):
+        args = [f"{fname}={getattr(self, fname)}" for fname in self._fields]
+        return f'{type(self).__name__}({", ".join(args)})'
+
 
 class ThisClass:  # Place holder
     pass
