@@ -224,8 +224,7 @@ class MetaStruct(type):
                             finfo = dispatch_arg(
                                 field.ftype._inspect_args, farg
                             )
-                            if hasattr(finfo, "_offsets"):  # is dinamic
-                                extra[field.index] = finfo
+                            extra[field.index] = finfo
                             offsets[field.index] = offset
                             offset += _to_slot_size(finfo.size)
                         # _offsets is used to because of field.get_offset(info)
@@ -406,6 +405,12 @@ class Struct(metaclass=MetaStruct):
         else:
             return longform
 
+    def __getstate__(self):
+        return self._buffer, self._offset
+
+    def __setstate__(self, state):
+        self._buffer, self._offset = state
+
     @classmethod
     def _gen_data_paths(cls, base=None):
         paths = []
